@@ -253,13 +253,13 @@ class SSHClient(object):
 
     @enter_and_leave_function
     def _scp_to_remote(self, local_path, remote_path):
-        """递归拷贝本地文件/文件夹到远端，确保父目录存在"""
+        """拷贝本地文件/目录到远端：文件用sftp，目录用scp -r递归拷贝"""
         local_path = Path(local_path).resolve()
         remote_path = Path(remote_path)
 
-        # 处理本地文件：确保远端父目录存在后再上传
+        # 处理本地文件：用sftp直接上传
         if local_path.is_file():
-            # 关键修复：创建文件的父目录（避免 "No such file" 错误）
+            # 确保远端父目录存在
             remote_parent = remote_path.parent
             mkdir_cmd = f"mkdir -p {remote_parent}"
             rs = self.exec(mkdir_cmd)
@@ -274,51 +274,45 @@ class SSHClient(object):
                 log.error(f" {self.__ip}:{self.__port} | 文件上传失败: {local_path} -> {remote_path}, 错误: {str(e)}")
                 return False
 
-            # 验证文件是否存在
-            rs = self.exec(f"ls {remote_path}")
-            if rs.exit_status_code != 0:
+            # 验证文件存在
+            if self.exec(f"ls {remote_path}").exit_status_code != 0:
                 log.warning(f" {self.__ip}:{self.__port} | 文件拷贝失败: 远端未找到 {remote_path}")
                 return False
             return True
 
-        # 处理本地文件夹：递归创建目录并拷贝内容
+        # 处理本地目录：用scp -r递归拷贝（不遍历文件）
         if local_path.is_dir():
-            # 创建远端根目录
-            mkdir_cmd = f"mkdir -p {remote_path}"
-            rs = self.exec(mkdir_cmd)
-            if rs.exit_status_code != 0:
-                log.error(f" {self.__ip}:{self.__port} | 无法创建远端根目录 {remote_path}，命令: {mkdir_cmd}")
+            # 构建scp命令：通过本地执行scp，将目录推送到远端
+            # 格式：scp -r <本地目录> <用户@ip:远端路径>
+            ssh_user = self.__username  # 假设self有SSH用户名属性（如root）
+            ssh_port = self.__port or 22  # 默认为22端口
+            # 远端路径需用引号包裹，避免特殊字符问题
+            remote_scp_path = f"{ssh_user}@{self.__ip}:{str(remote_path)}"
+            scp_cmd = [
+                "scp", "-r",
+                "-P", str(ssh_port),  # 指定SSH端口
+                str(local_path),  # 本地目录
+                remote_scp_path  # 远端目标路径
+            ]
+
+            # 执行scp命令（通过subprocess，利用本地scp客户端）
+            try:
+                # 隐藏scp输出，仅捕获错误（如需调试可添加stdout=subprocess.PIPE）
+                result = subprocess.run(
+                    scp_cmd,
+                    check=True,
+                    stdout=subprocess.PIPE,
+                    stderr=subprocess.PIPE,
+                    text=True
+                )
+                log.info(f" {self.__ip}:{ssh_port} | 目录递归拷贝完成: {local_path} -> {remote_path}")
+                return True
+            except subprocess.CalledProcessError as e:
+                log.error(
+                    f" {self.__ip}:{ssh_port} | 目录拷贝失败: 命令 {' '.join(scp_cmd)}，错误: {e.stderr}"
+                )
                 return False
 
-            # 遍历本地文件夹
-            for root, dirs, files in os.walk(local_path):
-                # 计算相对路径，保持目录结构
-                relative_root = Path(root).relative_to(local_path)
-                remote_current_dir = remote_path / relative_root
-
-                # 拷贝文件（关键：每个文件都确保其父目录存在）
-                for file in files:
-                    local_file = Path(root) / file
-                    remote_file = remote_current_dir / file
-
-                    # 强制创建当前文件的父目录（即使是子目录中的文件）
-                    remote_file_parent = remote_file.parent
-                    rs=self.exec(f"ls {remote_file_parent}")
-                    if rs.exit_status_code != 0:
-                        rs=self.exec(f"mkdir -p {remote_file_parent}")
-                        if rs.exit_status_code != 0:
-                            log.error(f" {self.__ip}:{self.__port} | 创建目录失败: {remote_file_parent}")
-                            return False
-                    # 上传文件
-                    try:
-                        self.__sftp.put(str(local_file), str(remote_file))
-                    except Exception as e:
-                        log.error(
-                            f" {self.__ip}:{self.__port} | 拷贝失败: {local_file} -> {remote_file}, 错误: {str(e)}")
-                        return False
-
-            return True
-
         # 本地路径无效
         log.error(f" {self.__ip}:{self.__port} | 本地路径无效: {local_path}（不是文件或文件夹）")
         return False
@@ -326,9 +320,9 @@ class SSHClient(object):
     @enter_and_leave_function
     def scp_to_remote(self, local_path, remote_path, timeout=120):
         try:
-            if not self.__ssh:
-                if not self.reconnect():
-                    raise RuntimeError("SSH连接未激活且重连失败")
+            # 确保SSH连接激活（目录拷贝依赖本地scp，也需基础连接验证）
+            if not self.__ssh and not self.reconnect():
+                raise RuntimeError("SSH连接未激活且重连失败")
             if not self.__sftp:
                 self.__sftp = self.__ssh.open_sftp()
 
@@ -343,6 +337,9 @@ class SSHClient(object):
                     if self.exec(f"rm -f {remote_path}").exit_status_code != 0:
                         log.error(f" {self.__ip}:{self.__port} | 无法删除远端冲突文件: {remote_path}")
                         return False
+                # 确保远端父目录存在（避免scp因父目录不存在失败）
+                remote_parent = remote_path.parent
+                self.exec(f"mkdir -p {remote_parent}")
 
             return self._scp_to_remote(local_path, remote_path)
         except Exception as e:
